@@ -52,7 +52,7 @@ static void log_entries(struct xlation *state)
 	session = &entries->session;
 
 	if (entries->bib_set) {
-		log_debug(state, "BIB entry: %pI6c#%u - %pI4#%u (%s)",
+		log_debug(state, "BIB entry: " BEPP,
 				&session->src6.l3, session->src6.l4,
 				&session->src4.l3, session->src4.l4,
 				l4proto_to_string(session->proto));
@@ -60,16 +60,10 @@ static void log_entries(struct xlation *state)
 		log_debug(state, "BIB entry: None");
 	}
 
-	if (entries->session_set) {
-		log_debug(state, "Session entry: %pI6c#%u - %pI6c#%u | %pI4#%u - %pI4#%u (%s)",
-				&session->src6.l3, session->src6.l4,
-				&session->dst6.l3, session->dst6.l4,
-				&session->src4.l3, session->src4.l4,
-				&session->dst4.l3, session->dst4.l4,
-				l4proto_to_string(session->proto));
-	} else {
+	if (entries->session_set)
+		log_debug(state, "Session entry: " SEPP, SEPA(session));
+	else
 		log_debug(state, "Session entry: None");
-	}
 }
 
 static verdict succeed(struct xlation *state)
